@@ -12,7 +12,9 @@ rss_parse <- function(response, list, clean_tags, parse_dates) {
       xml_text()
   )
   # optional metadata: language, copyright, managingEditor, webMaster, pubDate,
-  # lastBuildDate; category, generator, docs, cloud, ttl, image, textInput,
+  # lastBuildDate; category, generator, docs, cloud, link, managingEditor,
+  # podcast:guid, podcast:license, podcast:locked, podcast:funding,
+  # podcast:location, podcast:trailer, ttl, image, textInput,
   # skipHours, skipDays
   meta_optional <- tibble(
     feed_language = safe_run(channel, "first", "//*[name()='language']"),
@@ -27,6 +29,14 @@ rss_parse <- function(response, list, clean_tags, parse_dates) {
       )),
     feed_generator = safe_run(channel, "first", "//*[name()='generator']"),
     feed_docs = safe_run(channel, "first", "//*[name()='docs']"),
+    feed_managingEditor = safe_run(channel, "first", "//*[name()='managingEditor']"),
+    feed_webMaster = safe_run(channel, "first", "//*[name()='webMaster']"),
+    feed_guid = safe_run(channel, "first", "//*[name()='podcast:guid']"),
+    feed_license = safe_run(channel, "first", "//*[name()='podcast:license']"),
+    feed_locked = safe_run(channel, "first", "//*[name()='podcast:locked']"),
+    feed_funding = safe_run(channel, "first", "//*[name()='podcast:funding']"),
+    feed_location = safe_run(channel, "first", "//*[name()='podcast:location']"),
+    feed_trailer = safe_run(channel, "first", "//*[name()='podcast:trailer']"),
     feed_ttl = safe_run(channel, "first", "//*[name()='ttl']")
   )
   meta <- bind_cols(metadata, meta_optional)
@@ -39,14 +49,18 @@ rss_parse <- function(response, list, clean_tags, parse_dates) {
     item_title = map(res_entry, "title", .default = def) %>% unlist(),
     item_link = map(res_entry, "link", .default = def) %>% unlist(),
     item_description = map(res_entry, "description", .default = def) %>%
-      unlist() %>% discard(safe_check_comment),
+      replace_null() %>% discard(safe_check_comment) %>% unlist(),
     item_pub_date = map(res_entry, "pubDate", .default = def) %>% unlist(),
     item_guid = map(res_entry, "guid", .default = def) %>% unlist(),
     item_author = map(res_entry, "author", .default = def),
+    item_season = map(res_entry, "podcast:season", .default = def),
+    item_episode = map(res_entry, "podcast:episode", .default = def),
+    item_enclosure = map(res_entry, "enclosure", .default = def),
     item_category = map(res_entry_xml, ~ {
       xml_find_all(.x, "category") %>% map(xml_text)
     }),
-    item_comments = map(res_entry, "comments", .default = def) %>% unlist()
+    item_comments = map(res_entry, "comments", .default = def) %>% unlist(),
+    item_duration = map(res_entry, "duration", .default = def) %>% unlist()
   )
 
   # clean up
